Bucketing class abstract

Inheritance

Constructors

Bucketing({required List<String> nameComponents})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
nameComponents → List<String>
Specifies which human readable name components can be extracted from the bucket name.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bucketFor(String? pkg, String lib, String? cls, String? fun) → String
Constructs the bucket name from the given library name lib, class name cls and function name fun.
namesFromBucket(String bucket) → List<String>
Deconstructs bucket name into human readable components (the order matches one returned by nameComponents).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited